
Citing
======

If you find flipper useful in your research, please consider citing it. A suggested
reference is::

    Mark Bell. flipper (Computer Software).
    pypi.python.org/pypi/flipper, 2013--2018. Version <<version number>>

the BibTeX entry::

    @Misc{flipper,
        author = {Bell, Mark},
        title = {flipper (Computer Software)},
        howpublished = {\url{pypi.python.org/pypi/flipper}},
        year = {2013--2018},
        note = {Version <<version number>>}
    }

or the BibItem::

    \bibitem{flipper} Mark Bell: \emph{flipper (Computer Software)},
        \url{pypi.python.org/pypi/flipper}, (2013--2018),
        Version <<version number>>.
